@@ -1,5 +1,5 @@
 from pydantic import BaseModel, validator
-from typing import Union, List, Any, AnyStr, Dict
+from typing import Union, List, Any, AnyStr, Dict, Optional
 
 
 class ForeignKeySchema(BaseModel):
@@ -8,7 +8,6 @@ class ForeignKeySchema(BaseModel):
     column_name: str
     ondelete: str = "CASCADE"
     onupdate: str = "NO ACTION"
-    onupdate: str = "NO ACTION"
 
 
 class OptionsSchema(BaseModel):
@@ -61,25 +60,21 @@ class ColumnParametersSchema(BaseModel):
 
 
 class TablesInfo(BaseModel):
-    SourceTable: SourceTableSchema
-    DestinationTable: DestTableSchema
-    MigrationColumns: List[ColumnParametersSchema]
+    SourceTable: Optional[SourceTableSchema]
+    DestinationTable: Optional[DestTableSchema]
+    MigrationColumns: Optional[List[ColumnParametersSchema]]
 
 
 class MigrationTablesSchema(BaseModel):
-    migrationTable: TablesInfo
+    migrationTable: Optional[TablesInfo]
 
 
 class ConfigSchema(BaseModel):
     Configs: List[Union[SourceConfigSchema, DestinationConfigSchema]]
-    migrationTables: List[MigrationTablesSchema]
+    migrationTables: Optional[List[MigrationTablesSchema]]
     version: float
 
 
-
-
-
-
 class OptionsSchmea(BaseModel):
     options: Dict[str, str]
 
