@@ -1,28 +1,15 @@
-import logging
 from madmigration.db_init.connection_engine import SourceDB
 from madmigration.db_init.connection_engine import DestinationDB
-from madmigration.utils.helpers import detect_driver, get_cast_type
-from sqlalchemy import Column, MetaData, Table
-from madmigration.config.conf import Config
-from madmigration.mysqldb.type_convert import get_type_object
-from sqlalchemy import insert
-from sqlalchemy import (
-    Integer,
-    String,
-    DateTime,
-    Date,
-    BigInteger,
-    VARCHAR,
-    Float,
-    TIMESTAMP
-)
+from madmigration.utils.helpers import detect_driver
+from sqlalchemy import MetaData
+from madmigration.config.conf import ConfigYamlManager
+from madmigration.utils.logger import configure_logging
 
-
-logger = logging.getLogger(__name__)
+logger = configure_logging(__name__)
 
 
 class Controller:
-    def __init__(self, migration_config: Config):
+    def __init__(self, migration_config: ConfigYamlManager):
         
         self.config = migration_config
 
@@ -30,9 +17,6 @@ class Controller:
         self.source_db = SourceDB(self.config.source_uri)
         self.destination_db = DestinationDB(self.config.destination_uri)
         self.metadata = MetaData()
-        # Source and Destination Database - all tables (NOT MIGRATION TABLES!!!)
-        self.sourcedb_all_tables_names = self.source_db.engine.table_names()
-        self.destinationdb_all_tables_names = self.destination_db.engine.table_names()
 
         # All migration tables (Yaml file migrationTables)
         self.migration_tables = self.config.migrationTables
@@ -60,27 +44,13 @@ class Controller:
             logger.info(f"Detect SQL driver {self.destination_db.engine.name}")
             migrate = detect_driver(self.destinationdb_driver)
             
-            mig = migrate(self.config,self.destination_db)
+            mig = migrate(self.config, self.destination_db)
             mig.prepare_tables()
             mig.process()
             logger.info("Tables in destination db created successfully")
         except Exception as err:
             logger.error(err)
-            
-        
 
-    def get_column_type_from_source_table(self, table_name, column_name):
-        """
-        Get type of column in source table from Source Database
-        :param table_name: Table name
-        :param column_name: Column name
-        :return: Column type (Integer, Varchar, Float, Double, etc...)
-        """
-        tables = self.source_db.base.metadata.tables
-        table = tables.get(table_name)
-        for column in table.columns:
-            if column.name == column_name:
-                return column.type
 
     def run(self):
         # Looping in migrationTables
@@ -133,7 +103,7 @@ class NoSQLController:
     '''
     Class sturct works for transfering from postgresql database data to mongoDB database
     '''
-    def __init__(self, migration_config: Config):
+    def __init__(self, migration_config: ConfigYamlManager):
         
         self.config = migration_config
         self.source_db = self.config.source_uri
@@ -159,14 +129,3 @@ class NoSQLController:
       
         except Exception as err:
             print(err)
-
-    
-     
-        
-       
-        
-
-
-
-
-
