@@ -29,12 +29,12 @@ from sqlalchemy.dialects.postgresql import (
 from sqlalchemy import DateTime
 from sqlalchemy_utils import UUIDType
 from madmigration.basemigration.base import BaseMigrate
-from madmigration.config.conf import Config
+from madmigration.config.conf import ConfigYamlManager
 from pprint import pprint
 
 
 class PgMigrate(BaseMigrate): 
-    def __init__(self, config: Config, destination_db):
+    def __init__(self, config: ConfigYamlManager, destination_db):
         super().__init__(config, destination_db)
         self.collect_table_names()
 
